Documentation.addTranslations({
    "locale": "ca",
    "messages": {
        "%(filename)s &#8212; %(docstitle)s": "",
        "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "",
        "&#169; Copyright %(copyright)s.": "",
        ", in ": "",
        "About these documents": "Quant a aquests documents",
        "Automatically generated list of changes in version %(version)s": "Llista de canvis de la versi\u00f3 %(version)s generada autom\u00e0ticament",
        "C API changes": "Canvis a la API de C",
        "Changes in Version %(version)s &#8212; %(docstitle)s": "",
        "Collapse sidebar": "",
        "Complete Table of Contents": "Taula de Contingut Completa",
        "Contents": "",
        "Copyright": "Copyright",
        "Created using <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "Creat amb <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.",
        "Expand sidebar": "",
        "Full index on one page": "\u00cdndex complet en una p\u00e0gina",
        "General Index": "\u00cdndex General",
        "Global Module Index": "\u00cdndex Global de M\u00f2duls",
        "Go": "Ves a",
        "Hide Search Matches": "Oculta Resultats de Cerca",
        "Index": "\u00cdndex",
        "Index &ndash; %(key)s": "\u00cdndes &ndash; %(key)s",
        "Index pages by letter": "P\u00e0gines d'\u00edndex per lletra",
        "Indices and tables:": "\u00cdndexs i taules:",
        "Last updated on %(last_updated)s.": "\u00daltima actualitzaci\u00f3 el %(last_updated)s.",
        "Library changes": "Canvis a la llibreria",
        "Navigation": "Navegaci\u00f3",
        "Next topic": "Tema seg\u00fcent",
        "Other changes": "Altres canvis",
        "Overview": "Resum",
        "Permalink to this definition": "Link permanent a aquesta definici\u00f3",
        "Permalink to this headline": "Link permanent a aquest t\u00edtol",
        "Please activate JavaScript to enable the search\n    functionality.": "Activa JavaScript per utilitzar la funcionalitat\nde cerca.",
        "Preparing search...": "",
        "Previous topic": "Tema anterior",
        "Quick search": "Cerca r\u00e0pida",
        "Search": "Cerca",
        "Search Page": "P\u00e0gina de Cerca",
        "Search Results": "Resultats de la Cerca",
        "Search finished, found %s page(s) matching the search query.": "",
        "Search within %(docstitle)s": "Cerca dins de %(docstitle)s",
        "Searching": "",
        "Searching for multiple words only shows matches that contain\n    all words.": "",
        "Show Source": "Mostra Codi Font",
        "Table of Contents": "",
        "This Page": "Aquesta P\u00e0gina",
        "Welcome! This is": "",
        "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "",
        "all functions, classes, terms": "totes les funcions, classes, termes",
        "can be huge": "pot ser gegant",
        "last updated": "",
        "lists all sections and subsections": "llista totes les seccions i subseccions",
        "next chapter": "cap\u00edtol seg\u00fcent",
        "previous chapter": "cap\u00edtol anterior",
        "quick access to all modules": "acc\u00e9s r\u00e0pid a tots els m\u00f2duls",
        "search": "cerca",
        "search this documentation": "cerca aquesta documentaci\u00f3",
        "the documentation for": ""
    },
    "plural_expr": "(n != 1)"
});